@@ -85,7 +85,6 @@ class CreateFileExportUserJobRequest(AbstractModel):
         :type UserStoreId: str
         :param Format: 导出的数据类型
 
-<li> **JSON** </li>  JSON
 <li> **NDJSON** </li>  New-line Delimited JSON
 <li> **CSV** </li>  Comma-Separated Values
         :type Format: str
@@ -177,6 +176,16 @@ class CreateUserRequest(AbstractModel):
         :type Birthdate: int
         :param CustomizationAttributes: 自定义属性
         :type CustomizationAttributes: list of MemberMap
+        :param IndexedAttribute1: 索引字段1
+        :type IndexedAttribute1: str
+        :param IndexedAttribute2: 索引字段2
+        :type IndexedAttribute2: str
+        :param IndexedAttribute3: 索引字段3
+        :type IndexedAttribute3: str
+        :param IndexedAttribute4: 索引字段4
+        :type IndexedAttribute4: str
+        :param IndexedAttribute5: 索引字段5
+        :type IndexedAttribute5: str
         """
         self.UserStoreId = None
         self.PhoneNumber = None
@@ -188,6 +197,11 @@ class CreateUserRequest(AbstractModel):
         self.UserGroup = None
         self.Birthdate = None
         self.CustomizationAttributes = None
+        self.IndexedAttribute1 = None
+        self.IndexedAttribute2 = None
+        self.IndexedAttribute3 = None
+        self.IndexedAttribute4 = None
+        self.IndexedAttribute5 = None
 
 
     def _deserialize(self, params):
@@ -206,6 +220,11 @@ class CreateUserRequest(AbstractModel):
                 obj = MemberMap()
                 obj._deserialize(item)
                 self.CustomizationAttributes.append(obj)
+        self.IndexedAttribute1 = params.get("IndexedAttribute1")
+        self.IndexedAttribute2 = params.get("IndexedAttribute2")
+        self.IndexedAttribute3 = params.get("IndexedAttribute3")
+        self.IndexedAttribute4 = params.get("IndexedAttribute4")
+        self.IndexedAttribute5 = params.get("IndexedAttribute5")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -295,14 +314,21 @@ class DescribeUserByIdRequest(AbstractModel):
         :type UserStoreId: str
         :param UserId: 用户ID
         :type UserId: str
+        :param Original: 返回信息是否为原文
+
+<li> **false** </li>	默认，返回信息为脱敏信息
+<li> **true** </li>	返回用户信息原文
+        :type Original: bool
         """
         self.UserStoreId = None
         self.UserId = None
+        self.Original = None
 
 
     def _deserialize(self, params):
         self.UserStoreId = params.get("UserStoreId")
         self.UserId = params.get("UserId")
+        self.Original = params.get("Original")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -336,6 +362,94 @@ class DescribeUserByIdResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeUserRequest(AbstractModel):
+    """DescribeUser请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param UserStoreId: 用户目录ID
+        :type UserStoreId: str
+        :param Pageable: 分页数据
+        :type Pageable: :class:`tencentcloud.ciam.v20220331.models.Pageable`
+        :param Filters: 查询条件，根据propertycode和propertykey
+        :type Filters: list of QueryUserFilter
+        :param Original: 是否返回明文
+        :type Original: bool
+        :param Sort: 排序设置
+        :type Sort: :class:`tencentcloud.ciam.v20220331.models.Sort`
+        """
+        self.UserStoreId = None
+        self.Pageable = None
+        self.Filters = None
+        self.Original = None
+        self.Sort = None
+
+
+    def _deserialize(self, params):
+        self.UserStoreId = params.get("UserStoreId")
+        if params.get("Pageable") is not None:
+            self.Pageable = Pageable()
+            self.Pageable._deserialize(params.get("Pageable"))
+        if params.get("Filters") is not None:
+            self.Filters = []
+            for item in params.get("Filters"):
+                obj = QueryUserFilter()
+                obj._deserialize(item)
+                self.Filters.append(obj)
+        self.Original = params.get("Original")
+        if params.get("Sort") is not None:
+            self.Sort = Sort()
+            self.Sort._deserialize(params.get("Sort"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeUserResponse(AbstractModel):
+    """DescribeUser返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Total: 总条数
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Total: int
+        :param Pageable: 分页对象
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Pageable: :class:`tencentcloud.ciam.v20220331.models.Pageable`
+        :param Content: 用户列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Content: list of User
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Total = None
+        self.Pageable = None
+        self.Content = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Total = params.get("Total")
+        if params.get("Pageable") is not None:
+            self.Pageable = Pageable()
+            self.Pageable._deserialize(params.get("Pageable"))
+        if params.get("Content") is not None:
+            self.Content = []
+            for item in params.get("Content"):
+                obj = User()
+                obj._deserialize(item)
+                self.Content.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class ErrorDetails(AbstractModel):
     """失败详情
 
@@ -520,6 +634,16 @@ class ImportUser(AbstractModel):
         :type Salt: :class:`tencentcloud.ciam.v20220331.models.Salt`
         :param PasswordEncryptTypeEnum: 密码加密方式（SHA1;BCRYPT）
         :type PasswordEncryptTypeEnum: str
+        :param IndexedAttribute1: 索引字段1
+        :type IndexedAttribute1: str
+        :param IndexedAttribute2: 索引字段2
+        :type IndexedAttribute2: str
+        :param IndexedAttribute3: 索引字段3
+        :type IndexedAttribute3: str
+        :param IndexedAttribute4: 索引字段4
+        :type IndexedAttribute4: str
+        :param IndexedAttribute5: 索引字段5
+        :type IndexedAttribute5: str
         """
         self.UserName = None
         self.PhoneNumber = None
@@ -547,6 +671,11 @@ class ImportUser(AbstractModel):
         self.CustomizationAttributes = None
         self.Salt = None
         self.PasswordEncryptTypeEnum = None
+        self.IndexedAttribute1 = None
+        self.IndexedAttribute2 = None
+        self.IndexedAttribute3 = None
+        self.IndexedAttribute4 = None
+        self.IndexedAttribute5 = None
 
 
     def _deserialize(self, params):
@@ -583,6 +712,11 @@ class ImportUser(AbstractModel):
             self.Salt = Salt()
             self.Salt._deserialize(params.get("Salt"))
         self.PasswordEncryptTypeEnum = params.get("PasswordEncryptTypeEnum")
+        self.IndexedAttribute1 = params.get("IndexedAttribute1")
+        self.IndexedAttribute2 = params.get("IndexedAttribute2")
+        self.IndexedAttribute3 = params.get("IndexedAttribute3")
+        self.IndexedAttribute4 = params.get("IndexedAttribute4")
+        self.IndexedAttribute5 = params.get("IndexedAttribute5")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -617,7 +751,6 @@ class Job(AbstractModel):
         :type CreatedDate: int
         :param Format: 任务的数据类型
 
-<li> **JSON** </li>  JSON
 <li> **NDJSON** </li>  New-line Delimited JSON
 <li> **CSV** </li>  Comma-Separated Values
 注意：此字段可能返回 null，表示取不到有效值。
@@ -879,16 +1012,20 @@ class ListUserByPropertyRequest(AbstractModel):
         :type PropertyCode: str
         :param PropertyValue: 属性值
         :type PropertyValue: str
+        :param Original: 返回信息是否为原文
+        :type Original: bool
         """
         self.UserStoreId = None
         self.PropertyCode = None
         self.PropertyValue = None
+        self.Original = None
 
 
     def _deserialize(self, params):
         self.UserStoreId = params.get("UserStoreId")
         self.PropertyCode = params.get("PropertyCode")
         self.PropertyValue = params.get("PropertyValue")
+        self.Original = params.get("Original")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -941,10 +1078,13 @@ class ListUserRequest(AbstractModel):
 <li> **condition** </li>	Values = 查询条件，用户ID，用户名称，手机或邮箱
 <li> **userGroupId** </li>	Values = 用户组ID
         :type Filters: list of Filter
+        :param Original: 返回信息是否为原文
+        :type Original: bool
         """
         self.UserStoreId = None
         self.Pageable = None
         self.Filters = None
+        self.Original = None
 
 
     def _deserialize(self, params):
@@ -958,6 +1098,7 @@ class ListUserRequest(AbstractModel):
                 obj = Filter()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        self.Original = params.get("Original")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1174,6 +1315,42 @@ class Pageable(AbstractModel):
         
 
 
+class QueryUserFilter(AbstractModel):
+    """查询用户信息条件
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PropertyKey: 属性key
+        :type PropertyKey: str
+        :param PropertyValue: 属性value
+        :type PropertyValue: str
+        :param Logic: 逻辑值，等于true，不等于false
+        :type Logic: bool
+        :param OperateLogic: 操作逻辑符（支持> < = >= <=  != between）
+        :type OperateLogic: str
+        """
+        self.PropertyKey = None
+        self.PropertyValue = None
+        self.Logic = None
+        self.OperateLogic = None
+
+
+    def _deserialize(self, params):
+        self.PropertyKey = params.get("PropertyKey")
+        self.PropertyValue = params.get("PropertyValue")
+        self.Logic = params.get("Logic")
+        self.OperateLogic = params.get("OperateLogic")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ResetPasswordRequest(AbstractModel):
     """ResetPassword请求参数结构体
 
@@ -1356,6 +1533,34 @@ class SetPasswordResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class Sort(AbstractModel):
+    """查询用户排序
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PropertyKey: 排序字段的key，参考自定义属性
+        :type PropertyKey: str
+        :param Order: 升序或者降序，ASC/DESC
+        :type Order: str
+        """
+        self.PropertyKey = None
+        self.Order = None
+
+
+    def _deserialize(self, params):
+        self.PropertyKey = params.get("PropertyKey")
+        self.Order = params.get("Order")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class UpdateUserRequest(AbstractModel):
     """UpdateUser请求参数结构体
 
@@ -1383,6 +1588,16 @@ class UpdateUserRequest(AbstractModel):
         :type Birthdate: int
         :param CustomizationAttributes: 自定义属性
         :type CustomizationAttributes: list of MemberMap
+        :param IndexedAttribute1: 索引字段1
+        :type IndexedAttribute1: str
+        :param IndexedAttribute2: 索引字段2
+        :type IndexedAttribute2: str
+        :param IndexedAttribute3: 索引字段3
+        :type IndexedAttribute3: str
+        :param IndexedAttribute4: 索引字段4
+        :type IndexedAttribute4: str
+        :param IndexedAttribute5: 索引字段5
+        :type IndexedAttribute5: str
         """
         self.UserId = None
         self.UserStoreId = None
@@ -1394,6 +1609,11 @@ class UpdateUserRequest(AbstractModel):
         self.UserGroup = None
         self.Birthdate = None
         self.CustomizationAttributes = None
+        self.IndexedAttribute1 = None
+        self.IndexedAttribute2 = None
+        self.IndexedAttribute3 = None
+        self.IndexedAttribute4 = None
+        self.IndexedAttribute5 = None
 
 
     def _deserialize(self, params):
@@ -1412,6 +1632,11 @@ class UpdateUserRequest(AbstractModel):
                 obj = MemberMap()
                 obj._deserialize(item)
                 self.CustomizationAttributes.append(obj)
+        self.IndexedAttribute1 = params.get("IndexedAttribute1")
+        self.IndexedAttribute2 = params.get("IndexedAttribute2")
+        self.IndexedAttribute3 = params.get("IndexedAttribute3")
+        self.IndexedAttribute4 = params.get("IndexedAttribute4")
+        self.IndexedAttribute5 = params.get("IndexedAttribute5")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1609,6 +1834,21 @@ class User(AbstractModel):
         :param LockTime: 锁定时间点
 注意：此字段可能返回 null，表示取不到有效值。
         :type LockTime: int
+        :param IndexedAttribute1: 索引字段1
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IndexedAttribute1: str
+        :param IndexedAttribute2: 索引字段2
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IndexedAttribute2: str
+        :param IndexedAttribute3: 索引字段3
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IndexedAttribute3: str
+        :param IndexedAttribute4: 索引字段4
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IndexedAttribute4: str
+        :param IndexedAttribute5: 索引字段5
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IndexedAttribute5: str
         """
         self.UserId = None
         self.UserName = None
@@ -1646,6 +1886,11 @@ class User(AbstractModel):
         self.Version = None
         self.LockType = None
         self.LockTime = None
+        self.IndexedAttribute1 = None
+        self.IndexedAttribute2 = None
+        self.IndexedAttribute3 = None
+        self.IndexedAttribute4 = None
+        self.IndexedAttribute5 = None
 
 
     def _deserialize(self, params):
@@ -1690,6 +1935,11 @@ class User(AbstractModel):
         self.Version = params.get("Version")
         self.LockType = params.get("LockType")
         self.LockTime = params.get("LockTime")
+        self.IndexedAttribute1 = params.get("IndexedAttribute1")
+        self.IndexedAttribute2 = params.get("IndexedAttribute2")
+        self.IndexedAttribute3 = params.get("IndexedAttribute3")
+        self.IndexedAttribute4 = params.get("IndexedAttribute4")
+        self.IndexedAttribute5 = params.get("IndexedAttribute5")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
