@@ -210,6 +210,40 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateSchedule(self, request):
+        """对 COS 中指定 Bucket 的目录下上传的媒体文件，设置处理规则，包括：
+        1. 视频转码（带水印）；
+        2. 视频转动图；
+        3. 对视频按指定时间点截图；
+        4. 对视频采样截图；
+        5. 对视频截图雪碧图；
+        6. 对视频转自适应码流；
+        7. 智能内容审核（鉴黄、敏感信息检测）；
+        8. 智能内容分析（标签、分类、封面、按帧标签）；
+        9. 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
+
+        注意：创建编排成功后是禁用状态，需要手动启用。
+
+        :param request: Request instance for CreateSchedule.
+        :type request: :class:`tencentcloud.mps.v20190612.models.CreateScheduleRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.CreateScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSchedule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateScheduleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSnapshotByTimeOffsetTemplate(self, request):
         """创建用户自定义指定时间点截图模板，数量上限：16。
 
@@ -568,6 +602,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteSchedule(self, request):
+        """删除编排
+
+        :param request: Request instance for DeleteSchedule.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DeleteScheduleRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DeleteScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSchedule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteScheduleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteSnapshotByTimeOffsetTemplate(self, request):
         """删除用户自定义指定时间点截图模板。
 
@@ -936,6 +993,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSchedules(self, request):
+        """查询编排。
+
+        :param request: Request instance for DescribeSchedules.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeSchedulesRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeSchedulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSchedules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSchedulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSnapshotByTimeOffsetTemplates(self, request):
         """查询指定时间点截图模板，支持根据条件，分页查询。
 
@@ -1306,6 +1386,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DisableSchedule(self, request):
+        """禁用自动化触发编排任务。
+
+        :param request: Request instance for DisableSchedule.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DisableScheduleRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DisableScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DisableSchedule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DisableScheduleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisableWorkflow(self, request):
         """禁用工作流。
 
@@ -1356,6 +1459,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def EnableSchedule(self, request):
+        """启用自动化触发编排任务。
+
+        :param request: Request instance for EnableSchedule.
+        :type request: :class:`tencentcloud.mps.v20190612.models.EnableScheduleRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.EnableScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EnableSchedule", params, headers=headers)
+            response = json.loads(body)
+            model = models.EnableScheduleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def EnableWorkflow(self, request):
         """启用工作流。
 
@@ -1611,6 +1737,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifySchedule(self, request):
+        """修改编排
+
+        :param request: Request instance for ModifySchedule.
+        :type request: :class:`tencentcloud.mps.v20190612.models.ModifyScheduleRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.ModifyScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifySchedule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyScheduleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifySnapshotByTimeOffsetTemplate(self, request):
         """修改用户自定义指定时间点截图模板。
 
@@ -1965,6 +2114,29 @@ class MpsClient(AbstractClient):
             model = models.StopStreamLinkFlowResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def WithdrawsWatermark(self, request):
+        """提取视频中的盲水印。
+
+        :param request: Request instance for WithdrawsWatermark.
+        :type request: :class:`tencentcloud.mps.v20190612.models.WithdrawsWatermarkRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.WithdrawsWatermarkResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("WithdrawsWatermark", params, headers=headers)
+            response = json.loads(body)
+            model = models.WithdrawsWatermarkResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
